import outdent from 'outdent'
import { sentenceCase } from 'sentence-case'

import { getTags } from './get-tags'

import execa from 'execa'

export const formatChangelogEntry = async ({
  cwd,
  unreleased,
  packageName,
  version,
  categorizedCommits
}) => {
  const formattedChangelogEntry = []

  for (const category in categorizedCommits) {
    const { commits } = categorizedCommits[category]

    if (!commits.length) continue

    const formattedNote = outdent`
      ### ${sentenceCase(category)}

      - ${commits.join('\n- ').trim()}
    `
    formattedChangelogEntry.push(formattedNote)
  }

  if (!unreleased) {
    let date = ''

    const [versionTag] = await getTags({ tag: 'v' + version, cwd, packageName })

    if (versionTag) {
      let params = ['show', '-s', '--format=%cs', versionTag]
      const { stdout: releaseDate } = await execa('git', params, { cwd })
      date = releaseDate
    } else {
      const [releaseDate] = new Date().toISOString().split('T')
      date = releaseDate
    }
    formattedChangelogEntry.unshift(`## ${version}`, `_${date}_`)
  } else {
    formattedChangelogEntry.unshift('## Unreleased')
  }

  // Divide sections with a line break
  return formattedChangelogEntry.join('\n\n')
}
